@@ -486,7 +486,10 @@ class TeslaCar:
     @property
     def steering_wheel_heater(self) -> bool:
         """Return steering wheel heater option."""
-        return self._vehicle_data.get("climate_state", {}).get("steering_wheel_heater") is not None
+        return (
+            self._vehicle_data.get("climate_state", {}).get("steering_wheel_heater")
+            is not None
+        )
 
     @property
     def tpms_pressure_fl(self) -> float:
@@ -555,6 +558,28 @@ class TeslaCar:
             return False
         return True
 
+    @property
+    def is_remote_start(self) -> bool:
+        """Return if remote start active."""
+        return self._vehicle_data.get("vehicle_state", {}).get("remote_start")
+
+    @property
+    def is_valet_mode(self) -> bool:
+        """Return state of valet mode."""
+        return self._vehicle_data.get("vehicle_state", {}).get("valet_mode")
+
+    @property
+    def is_auto_seat_climate_left(self) -> bool:
+        """Return state of valet mode."""
+        return self._vehicle_data.get("climate_state", {}).get("auto_seat_climate_left")
+
+    @property
+    def is_auto_seat_climate_right(self) -> bool:
+        """Return state of valet mode."""
+        return self._vehicle_data.get("climate_state", {}).get(
+            "auto_seat_climate_right"
+        )
+
     async def _send_command(
         self, name: str, *, path_vars: dict, wake_if_asleep: bool = False, **kwargs
     ) -> dict:
@@ -586,7 +611,11 @@ class TeslaCar:
             _LOGGER.debug("Attempted to update car id %d with empty car info", self.id)
             return
         if car["vin"] != self.vin:
-            _LOGGER.error("Failed updating car info: new VIN (%s) doesn't match existing vin (%s)", car["vin"][-5:], self.vin[-5:])
+            _LOGGER.error(
+                "Failed updating car info: new VIN (%s) doesn't match existing vin (%s)",
+                car["vin"][-5:],
+                self.vin[-5:],
+            )
             return
         self._car.update(car)
 
@@ -763,6 +792,28 @@ class TeslaCar:
             }
             self._vehicle_data["climate_state"].update(params)
 
+    async def remote_auto_seat_climate_request(
+        self, seat_id: int, enable: bool
+    ) -> None:
+        """Send command to change seat climate to auto.
+
+        Args
+            seat_id: 0 (front left), 1 (front right)
+            enable: 'True' to enable, 'False' to diable
+
+        """
+
+        data = await self._send_command(
+            "REMOTE_AUTO_SEAT_CLIMATE_REQUEST",
+            path_vars={"vehicle_id": self.id},
+            auto_seat_position=seat_id,
+            auto_climate_on=enable,
+            wake_if_asleep=True,
+        )
+        if data and data["response"]["result"] is True:
+            params = {f"auto_seat_climate_{SEAT_ID_MAP[seat_id]}": enable}
+            self._vehicle_data["climate_state"].update(params)
+
     async def set_heated_steering_wheel(self, value: bool) -> None:
         """Send command to set heated steering wheel."""
         data = await self._send_command(
@@ -1016,3 +1067,43 @@ class TeslaCar:
                 "rp_window": 0,
             }
             self._vehicle_data["vehicle_state"].update(params)
+
+    async def valet_mode(self, enable, pin) -> None:
+        """Set Valet Mode."""
+        data = await self._send_command(
+            "SET_VALET_MODE",
+            path_vars={"vehicle_id": self.id},
+            on=enable,
+            pin=pin,
+            wake_if_asleep=True,
+        )
+
+        if data and data["response"]:
+            _LOGGER.debug("Valet mode response: %s", data["response"])
+            result = data["response"]["result"]
+            reason = data["response"]["reason"]
+            if result is False:
+                _LOGGER.debug("Error calling valet mode: %s", reason)
+            else:
+                if enable:
+                    params = {"valet_mode": True}
+                else:
+                    params = {"valet_mode": False}
+                self._vehicle_data["vehicle_state"].update(params)
+
+    async def remote_start(self) -> None:
+        """Remote start."""
+        data = await self._send_command(
+            "REMOTE_START",
+            path_vars={"vehicle_id": self.id},
+            wake_if_asleep=True,
+        )
+
+        if data and data["response"]:
+            _LOGGER.debug("Remote start response: %s", data["response"])
+            result = data["response"]["result"]
+            reason = data["response"]["reason"]
+            if result is False:
+                _LOGGER.debug("Error calling remote start: %s", reason)
+            else:
+                self._vehicle_data["vehicle_state"].update({"remote_start": True})
